[% USE uri = Class('Rubric::WebApp::URI') %]
<html>
<head>
	<title>Rubric</title>
	<link href='[% uri.stylesheet %]' rel='stylesheet' type='text/css' />
</head>
<body>
	<h1>
		rubric
	</h1>
	[% PROCESS "toolbar.html" %]

	<h2>links</h2>
	[% WHILE (link = links.next) %]
	[% PROCESS "link.html" %]
	[% END %]

	<div>
		[% count %] links;
		[% per_page %] items max per page;
		this is page [% page %]
	</div>

	</body>
</html>
