	<div class='toolbar'>
		<span style='float:left'>
		[% IF current_user %]
			you are: [% current_user %]
		[% ELSE %]
			not logged in
		[% END %]
		</span>
		<a href='[% uri.root %]'>(root)</a>
		[% IF current_user %]
		| <a href='[% uri.entries( user => current_user ) %]'>entries</a>
		[% END %]
		[% IF current_user %]
		| <a href='[% uri.post_entry %]'>new entry</a>
		[% END %]
		[% IF current_user %]
		| <a href='[% uri.logout %]'>logout</a>
		[% ELSE %]
		| <a href='[% uri.login %]'>login</a>
		[% END %]
	</div>
