body {
	background-color: #eee;
	color: black;
	margin: 0;
	font-size: 80%;
}

a { color: rgb(0,80,191) }
a:visited { color: rgb(44,127,113) }

h1 { 
	padding: 0;
	background-color: #ddd;
	padding-left: 0.5em;
	padding-bottom: 1%;
	margin-bottom: 0;
}

h2 {
	margin-top: .25em;
	margin-left: .5em;
	margin-bottom: 0;
}

h3 {
	padding-left: 1em;
	margin-bottom: .25em;
}

h3.error {
	color: #b00;
}

div.toolbar {
	text-align: right;
	background-color: #bbb;
	margin-top: 0;
	padding: 0.25em 0.5em;
}

div.toolbar span.current_user {
	float: left;
}

div.toolbar a {
	text-decoration: none;
}

div.delete {
	padding-left: 1em;
}

div.entry {
	margin-left: 1em;
	margin-right: 1em;
	padding: .5em;
}

div.entry div.uri {
	font-size: 110%;
}

div.entry div.description {
	font-style: italic
}

div.entry div.created,
div.entry div.tags {
	padding-left: 1em;
}

div.entry.longform h2 {
	margin-left: 0em;
}

div.entry.longform div.created {
	padding-left: 0em;
}

div.entry.longform div.body {
	padding: 1em;
	margin-top: 1em;
	border: 1px black solid;
	background-color: #f8f8f8;
}

div.taglist {
	float: right;
	padding-left: .5%;
	padding-right: .5%;
	padding-bottom: 1em;
	background-color: #bbb;
	margin: 1%;
	font-size: 85%;
}

div.taglist a { text-decoration: none }

div.taglist h3 { text-align: center; }

span.tag_count { float: left; text-align: right; width: 2em; }

div.entryform table th {
	text-align: right;
}

div.must_login {
	margin-left: 1em;
	margin-right: 1em;
	padding: .5em;
}

div.loginform, div.entryform {
	margin-left: 1em;
	margin-right: 1em;
	padding: .5em;
}

form#loginform td.submit, form#entryform td.submit {
	text-align: right
}

div.entries {
	border-bottom: thin black solid;
}

div.next_page { float: right; padding-right: 1em; }
div.prev_page { float: left ; padding-left : 1em; }

div.page_num,
div.page_size { text-align: center }
