	[% IF existing_entry.created %]
	<h2>revise entry</h2>
	<h3>originally created: [% existing_entry.created %]</h3>
	[% IF existing_entry.created != existing_entry.modified %]
	<h3>last modified: [% existing_entry.created %]</h3>
	[% END %]
	<div class='delete'>
		<a href='[% uri.delete_entry(existing_entry) %]'>delete this entry</a>
	</div>
	[% ELSE %]
	<h2>new entry</h2>
	[% END %]
	<div class='entryform'>
		<form id='entryform' action='[% uri.post_entry %]'>
			<table>
			[% FOREACH param = [ "uri", "title", "description", "tags" ] %]
				<tr>
					<th>[% param %]</th>
					<td><input name='[% param %]' value='[% 
					form.$param OR existing_entry.$param.join(" ")
					%]' size='75' />
				</tr>
			[% END %]
				<tr><td class='submit' colspan='2'>
					<input type='submit' name='submit' value='save' />
				</td></tr>
				<tr>
					<th style='vertical-align:top'>body</th>
					<td><textarea name='body' cols='72' rows='10'>[% existing_entry.body %]</textarea></td>
				</tr>
				<tr><td class='submit' colspan='2'>
					<input type='hidden' name='entryid' value='[%existing_entry.id%]' />
					<input type='submit' name='submit' value='save' />
				</td></tr>
			</table>
		</form>
	</div>
