	<div class='entry longform'>
		<h2 class='created'>
			[% entry.created.strftime("%Y-%m-%d %H:%M") %]
		</h2>
		<h2 class='uri'>
			[% IF entry.link %]
				<a href='[% entry.link %]'>[% entry.title %]</a>
			[% ELSE %]
				[% entry.title %]
			[% END %]
			[% IF current_user == entry.user %]
			<a href='[% uri.edit_entry(entry) %]'>(edit)</a>
			[% END %]
		</h2>
		[% IF entry.description %]
		<div class='description'>[% entry.description %]</div>
		[% END %]
		<div class='created'>
			[% FOREACH tag = entry.tags %]
			<a href='[% uri.entries(user => user, tags => [ tag ]) %]'>[% tag %]</a>
			[% END %]
			[% "by " _ entry.user UNLESS user %]
		</div>
		[% IF entry.body %]
		<div class='body'>
		[% entry.body %]
		</div>
		[% END %]
	</div>
