	[% IF user %]
	<div class='taglist'>
	<h3>all tags</h3>
	[% FOREACH tag = user.tags_counted %]
	<div class='tag'>
		<span class='tag_count'>[% tag.1 %]</span>
		&nbsp;
		<a href='[% uri.entries(user => user, tags => [ tag.0 ]) %]'>
			[% tag.0 %]
		</a>
		&nbsp;
	</div>
	[% END %]
	</div>
	[% END %]

	[% IF user && tags.size %]
	<div class='taglist'>
	<h3>related tags</h3>
	[% FOREACH tag = user.related_tags_counted(tags) %]
	<div class='tag'>
	<span class='tag_count'>[% tag.1 %]</span>
	&nbsp;
	<a class='plus' href='[% uri.entries(user => user, tags => tags.merge( [ tag.0 ] )) %]'>+</a>
	<a href='[% uri.entries(user => user, tags => [ tag.0 ] ) %]'>[% tag.0 %]</a>
	&nbsp;
	</div>
	[% END %]
	<br />
	[% FOREACH tag = tags %]
	<div class='tag'>
	<span class='tag_count'>&nbsp;</span>
	&nbsp;
	<a class='plus' href='[% uri.entries(user => user, tags => remove(tag, tags)) %]'>-</a>
	<a href='[% uri.entries(user => user, tags => [ tag ] ) %]'>[% tag %]</a>
	&nbsp;</div>
	[% END %]
	</div>
	[% END %]

	[% IF recent_tags.size %]
	<div class='taglist'>
	<h3>recent tags</h3>
	[% FOREACH tag = recent_tags %]
	<div class='tag'>
		<span class='tag_count'>[% tag.1 %]</span>
		&nbsp;
		<a href='[% uri.entries(tags => [ tag.0 ]) %]'>[% tag.0 %]</a>
		&nbsp;
	</div>
	[% END %]
	</div>
	[% END %]

	<h2>entries</h2>
	<div class='entries'>
	[% WHILE (entry = entries.next) %]
	[% PROCESS "entry.html" %]
	[% END %]
	</div>

	[% PROCESS "page_data.html" %]
